@@ -25,6 +25,7 @@
 # All comments below are strictly for development usage and
 # reference.
 
+import os
 import imp
 import django
 try:
@@ -82,11 +83,45 @@ USE_I18N = True
 # calendars according to the current locale
 USE_L10N = True
 
-# List of callables that know how to import templates from various sources.
-TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.Loader',
-    'django.template.loaders.app_directories.Loader',
-)
+if django.VERSION < (1, 8):
+    # List of callables that know how to import templates from various sources.
+    TEMPLATE_LOADERS = (
+        'django.template.loaders.filesystem.Loader',
+        'django.template.loaders.app_directories.Loader',
+    )
+else:
+    PROJECT_DIR = os.path.dirname(os.path.join(os.path.dirname(__file__), '..', '..'))
+    TEMPLATES = [
+        {
+            'BACKEND': 'django.template.backends.django.DjangoTemplates',
+            'DIRS': [
+                # insert your TEMPLATE_DIRS here
+                os.path.join(PROJECT_DIR, 'templates'),
+                os.path.join(PROJECT_DIR, '..', '..', 'lava_scheduler_app', 'templates', 'lava_scheduler_app'),
+                os.path.join(PROJECT_DIR, '..', '..', 'dashboard_app', 'templates', 'dashboard_app'),
+                os.path.join(PROJECT_DIR, '..', '..', 'lava_results_app', 'templates', 'lava_results_app'),
+                os.path.join(PROJECT_DIR, '..', '..', 'google_analytics', 'templates', 'google_analytics'),
+                os.path.join(PROJECT_DIR, '..', '..', 'lava_markitup', 'templates', 'lava_markitup'),
+            ],
+            'OPTIONS': {
+                'context_processors': [
+                    # Insert your TEMPLATE_CONTEXT_PROCESSORS here
+                    "django.contrib.auth.context_processors.auth",
+                    "django.template.context_processors.debug",
+                    "django.template.context_processors.i18n",
+                    "django.template.context_processors.media",
+                    "django.template.context_processors.request",
+                    "django.template.context_processors.static",
+                    "lava_server.context_processors.lava",
+                    "lava_server.context_processors.ldap_available",
+                ],
+                'loaders': [
+                    'django.template.loaders.filesystem.Loader',
+                    'django.template.loaders.app_directories.Loader',
+                ]
+            },
+        },
+    ]
 
 MIDDLEWARE_CLASSES = [
     'django.middleware.csrf.CsrfViewMiddleware',
@@ -153,11 +188,7 @@ INSTALLED_APPS = [
 if USE_OPENID_AUTH:
     INSTALLED_APPS += ['django_openid_auth']
 
-if django.VERSION < (1, 7):
-    # Django 1.7 has built-in migration suppport
-    INSTALLED_APPS += ['south']
-else:
-    TEST_RUNNER = 'django.test.runner.DiscoverRunner'
+TEST_RUNNER = 'django.test.runner.DiscoverRunner'
 
 if devserver_import:
     INSTALLED_APPS += ['devserver']
@@ -168,19 +199,20 @@ if django_extensions_import:
 if hijack_import:
     INSTALLED_APPS += ['hijack']
 
-TEMPLATE_CONTEXT_PROCESSORS = [
-    "django.contrib.auth.context_processors.auth",
-    "django.core.context_processors.debug",
-    "django.core.context_processors.i18n",
-    "django.core.context_processors.media",
-    "django.core.context_processors.request",
-    "django.core.context_processors.static",
-    "lava_server.context_processors.lava",
-    "lava_server.context_processors.ldap_available",
-]
+if django.VERSION < (1, 8):
+    TEMPLATE_CONTEXT_PROCESSORS = [
+        "django.contrib.auth.context_processors.auth",
+        "django.core.context_processors.debug",
+        "django.core.context_processors.i18n",
+        "django.core.context_processors.media",
+        "django.core.context_processors.request",
+        "django.core.context_processors.static",
+        "lava_server.context_processors.lava",
+        "lava_server.context_processors.ldap_available",
+    ]
 
-if USE_OPENID_AUTH:
-    TEMPLATE_CONTEXT_PROCESSORS += ['lava_server.context_processors.openid_available']
+    if USE_OPENID_AUTH:
+        TEMPLATE_CONTEXT_PROCESSORS += ['lava_server.context_processors.openid_available']
 
 AUTHENTICATION_BACKENDS = (
     'django.contrib.auth.backends.ModelBackend',
@@ -206,8 +238,8 @@ RESTRUCTUREDTEXT_FILTER_SETTINGS = {"initial_header_level": 4}
 GOOGLE_ANALYTICS_MODEL = True
 
 ME_PAGE_ACTIONS = [
-    ("django.contrib.auth.views.password_change", "Change your password"),
-    ("django.contrib.auth.views.logout", "Sign out"),
+    ("password_change", "Change your password"),
+    ("logout", "Sign out"),
 ]
 
 ALLOWED_HOSTS = ['*']
