@@ -89,13 +89,51 @@ STATIC_ROOT = os.path.join(PROJECT_STATE_DIR, "static")
 SECRET_KEY = '00000000000000000000000000000000000000000000000000'
 
 # Use templates from the checkout directory
-TEMPLATE_DIRS = (
-    os.path.join(PROJECT_SRC_DIR, "templates"),
-)
+if django.VERSION < (1, 8):
+    TEMPLATE_DIRS = (
+        os.path.join(PROJECT_SRC_DIR, 'lava_scheduler_app', 'templates', 'lava_scheduler_app'),
+        os.path.join(PROJECT_SRC_DIR, 'dashboard_app', 'templates', 'dashboard_app'),
+        os.path.join(PROJECT_SRC_DIR, 'lava_results_app', 'templates', 'lava_results_app'),
+        os.path.join(PROJECT_SRC_DIR, 'google_analytics', 'templates', 'google_analytics'),
+        os.path.join(PROJECT_SRC_DIR, 'lava_markitup', 'templates', 'lava_markitup'),
+        os.path.join(PROJECT_SRC_DIR, "templates"),
+    )
+else:
+    TEMPLATES = [
+        {
+            'BACKEND': 'django.template.backends.django.DjangoTemplates',
+            'DIRS': [
+                os.path.join(PROJECT_SRC_DIR, '..', 'lava_server', 'templates'),
+                os.path.join(PROJECT_SRC_DIR, '..', 'lava_scheduler_app', 'templates', 'lava_scheduler_app'),
+                os.path.join(PROJECT_SRC_DIR, '..', 'dashboard_app', 'templates', 'dashboard_app'),
+                os.path.join(PROJECT_SRC_DIR, '..', 'lava_results_app', 'templates', 'lava_results_app'),
+                os.path.join(PROJECT_SRC_DIR, '..', 'google_analytics', 'templates', 'google_analytics'),
+                os.path.join(PROJECT_SRC_DIR, '..', 'lava_markitup', 'templates', 'lava_markitup'),
+            ],
+            'OPTIONS': {
+                'context_processors': [
+                    # Insert your TEMPLATE_CONTEXT_PROCESSORS here
+                    "django.contrib.auth.context_processors.auth",
+                    "django.template.context_processors.debug",
+                    "django.template.context_processors.i18n",
+                    "django.template.context_processors.media",
+                    "django.template.context_processors.request",
+                    "django.template.context_processors.static",
+                    "lava_server.context_processors.lava",
+                    "lava_server.context_processors.ldap_available",
+                ],
+                'loaders': [
+                    'django.template.loaders.filesystem.Loader',
+                    'django.template.loaders.app_directories.Loader',
+                ]
+            },
+        },
+    ]
+
 
 # Serve static files used by lava-server from the checkout directory
 STATICFILES_DIRS = [
-    ('lava-server', os.path.join(PROJECT_SRC_DIR, 'htdocs'))]
+    ('lava-server', os.path.join(PROJECT_SRC_DIR, 'lava-server'))]
 
 
 # Try using devserver if available, devserver is a very useful extension that
